<?php

namespace App\Factory;

use App\Exception;

class StoreFactory {
    private $connection;
    
    public function __construct (\Doctrine\DBAL\Connection $connection) {
        $this->connection = $connection;
    }
    
    public function getStandartVendor ($branch) {
        $sql = "
            SELECT CDVENDEDOR
              FROM PARAVEND
            WHERE CDFILIAL = :CDFILIAL";
            
        $params = array(
            ":CDFILIAL" => $branch    
        );
        
        $vendor = $this->connection->fetchAll($sql, $params);
        
        if (empty($vendor)) throw new Exception\ParamsException("Não foi encontrado vendedor padrão para a filial - $branch", 101);
        if (!isset($vendor[0]["CDVENDEDOR"])) throw new Exception\ParamsException("Não foi encontrado vendedor padrão para a filial - $branch", 101);
        
        return $vendor[0]["CDVENDEDOR"];
    }
    
    public function getStandartStore ($branch, $vendor) {
        $sql = "
            SELECT C.CDCAIXA, C.CDLOJA , V.CDOPERADOR, L.NRMESAPADRAO AS NRMESA,
              L.IDPOSOBSPED , L.IDLUGARMESA
            FROM CAIXA C , VENDEDOR V, LOJA L
            WHERE C.CDCAIXA    = V.CDCAIXA
              AND C.CDFILIAL   = :CDFILIAL
              AND V.CDVENDEDOR = :CDVENDEDOR
              AND C.CDLOJA     = L.CDLOJA
              AND C.CDFILIAL   = L.CDFILIAL";
            
        $params = array(
            ":CDFILIAL"   => $branch,
            ":CDVENDEDOR" => $vendor
        );
        
        $store = $this->connection->fetchAll($sql, $params);
        
        if (empty($store)) throw new Exception\ParamsException("Não foi encontrada loja padrão para a filial - $branch", 102);
        if (!isset($store[0]["CDLOJA"])) throw new Exception\ParamsException("Não foi encontrada loja padrão para a filial - $branch", 102);
        
        return $store[0];
    }
    
    public function getStandartCashier ($branch, $vendor) {
        $sql = "
            SELECT CDCAIXA, CDOPERADOR
              FROM VENDEDOR
            WHERE CDFILIAL   = :CDFILIAL
              AND CDVENDEDOR = :CDVENDEDOR";
            
        $params = array(
            ":CDFILIAL"   => $branch,
            ":CDVENDEDOR" => $vendor
        );
        
        $cashier = $this->connection->fetchAll($sql, $params);
        
        if (empty($cashier)) throw new Exception\ParamsException("Não foi encotrado caixa padrão para a filial - $branch", 103);
        if (!isset($cashier[0]["CDCAIXA"])) throw new Exception\ParamsException("Não foi encotrado caixa padrão para a filial - $branch", 103);
        
        return $cashier[0];
    }
    
    public function getProductControlId ($branch, $store) {
        $sql = "
            SELECT IDCONTROPROD
              FROM LOJA
            WHERE CDFILIAL = :CDFILIAL
              AND CDLOJA = :CDLOJA";
              
        $params = array(
            ":CDFILIAL" => $branch,
            ":CDLOJA"   => $store["CDLOJA"]
        );
        
        $idControlProd = $this->connection->fetchAll($sql, $params);
        
        if (empty($idControlProd)) 
            throw new Exception\ParamsException("A tela de controle de produção não está parametrizada para a filial - $branch", 104);
        if (!isset($idControlProd[0]["IDCONTROPROD"]))
            throw new Exception\ParamsException("A tela de controle de produção não está parametrizada para a filial - $branch", 104);
        
        return $idControlProd[0]["IDCONTROPROD"];
    }
    
}
