<?php

namespace App\Service;

use App\Exception as Exception;

class ConsumerService {

    private $util;
    private $consumerFactory;
    private $branchFactory;
    
    public function __construct (\App\Util\Util $util, 
                                 \App\Factory\ConsumerFactory $consumerFactory, 
                                 \App\Factory\BranchFactory $branchFactory) {

        $this->util             = $util;
        $this->consumerFactory  = $consumerFactory;
        $this->branchFactory    = $branchFactory;
    }

    public function processConsumer($generalParams, $orderData) {
        
        $consumer          = $this->consumerFactory->getStandardConsumer($generalParams["CDFILIAL"]);
        $branchAddressInfo = $this->branchFactory->getAddressInfo($generalParams["CDFILIAL"]);
        $address           = $this->processAddressInformation($orderData, $branchAddressInfo, $generalParams);

        if (empty($consumer["CDMUNICIPIO"])) 
            $consumer["CDMUNICIPIO"] = $this->consumerFactory->getCityCode($orderData["uf"], $orderData["city"]);

        if (empty($consumer["CDMUNICIPIO"]))
            $consumer["CDMUNICIPIO"] = $this->branchFactory->getBranchCityCode($generalParams["CDFILIAL"]);
            
        $consumer["DSAREAATEND"] = "";
        
        return array_merge($consumer, $address);
    }
    
    private function processAddressInformation ($orderData, $branchAddressInfo, $generalParams) {
        $consumer = null;
        
        $consumer["cep"]          = $orderData["cep"];
        $consumer["street"]       = $orderData["street"];
        $consumer["number"]       = $orderData["number"];
        $consumer["neighborhood"] = $orderData["neighborhood"];
        $consumer["city"]         = $orderData["city"];
        
        $consumer["CDMUNICIPIO"] = $branchAddressInfo["CDMUNICIPIO"];
        $consumer["SGESTADO"]    = $branchAddressInfo["SGESTADO"];
        $consumer["CDBAIRRO"]    = $this->consumerFactory->getNeighborhoodCode($consumer);
        
        if ($generalParams["TOGO"]) {
            $consumer["cep"]          = preg_replace("/[^0-9]/", "", $branchAddressInfo["NRCEPFILI"]);
            $consumer["street"]       = $branchAddressInfo["DSENDEFILI"];
            $consumer["neighborhood"] = $branchAddressInfo["NMBAIRFILI"];
        }
        
        $consumer["complement"]      = $orderData["complement"];
        $consumer["reference_point"] = $orderData["reference_point"];
        
        return $consumer;
    }
}
